﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using MindFusion.Scheduling;
using MindFusion.Scheduling.Wpf;

namespace WpfPlannerResourceViewAppearance
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		public MainWindow()
		{
			InitializeComponent();

			calendar.ResourceViewSettings.LaneSize = 54;

			FontFamily font = new FontFamily("Segoe UI");
			FontFamily headerFont = new FontFamily("Segoe UI Light");
			Brush borderBrush = new SolidColorBrush(Color.FromArgb(255, 224, 224, 224));

			// Customizing the control
			calendar.ResourceViewSettings.CalendarStyle.Background = Brushes.White;

			// Customizing row headers
			calendar.ResourceViewSettings.ExpandableRows = false;
			calendar.ResourceViewSettings.HeaderStyle.FontFamily = headerFont;
			calendar.ResourceViewSettings.HeaderStyle.FontSize = 13;
			calendar.ResourceViewSettings.HeaderStyle.Foreground = new SolidColorBrush(Color.FromArgb(255, 64, 64, 64));
			calendar.ResourceViewSettings.HeaderStyle.Background = Brushes.White;
			calendar.ResourceViewSettings.HeaderStyle.BorderBrush = borderBrush;
			calendar.ResourceViewSettings.HeaderStyle.BorderThickness = new Thickness(0, 0, 0, 1);

			// Customizing cells
			calendar.ResourceViewSettings.CellStyle.Background = Brushes.White;
			calendar.ResourceViewSettings.CellStyle.BorderBrush = borderBrush;
			calendar.ResourceViewSettings.WeekendStyle.Background = new SolidColorBrush(Color.FromArgb(255, 250, 250, 250));
			calendar.ResourceViewSettings.WeekendStyle.BorderBrush = borderBrush;

			// Customizing the timelines
			calendar.ResourceViewSettings.BottomTimelineSettings.CalendarStyle.Background = Brushes.White;
			calendar.ResourceViewSettings.BottomTimelineSettings.CalendarStyle.BorderBrush = borderBrush;
			calendar.ResourceViewSettings.BottomTimelineSettings.CalendarStyle.FontFamily = headerFont;
			calendar.ResourceViewSettings.BottomTimelineSettings.CalendarStyle.FontSize = 13;
			calendar.ResourceViewSettings.BottomTimelineSettings.CalendarStyle.FontWeight = FontWeights.Normal;
			calendar.ResourceViewSettings.BottomTimelineSettings.NowFillBrush = Brushes.Transparent;
			calendar.ResourceViewSettings.MiddleTimelineSettings.CalendarStyle.Background = Brushes.White;
			calendar.ResourceViewSettings.MiddleTimelineSettings.CalendarStyle.BorderBrush = borderBrush;
			calendar.ResourceViewSettings.MiddleTimelineSettings.CalendarStyle.FontFamily = headerFont;
			calendar.ResourceViewSettings.MiddleTimelineSettings.CalendarStyle.FontSize = 13;
			calendar.ResourceViewSettings.MiddleTimelineSettings.CalendarStyle.FontWeight = FontWeights.Normal;
			calendar.ResourceViewSettings.MiddleTimelineSettings.NowFillBrush = Brushes.Transparent;

			calendar.ItemSettings.UseExtendedStyles = false;
			calendar.ItemSettings.CalendarStyle.FontFamily = headerFont;
			calendar.ItemSettings.CalendarStyle.Background = Brushes.White;
			calendar.ItemSettings.CalendarStyle.BorderBrush = Brushes.SlateGray;
			calendar.ItemSettings.SelectedItemStyle.FontFamily = headerFont;
			calendar.ItemSettings.SelectedItemStyle.Background = new SolidColorBrush(Color.FromArgb(255, 247, 250, 255));
			calendar.ItemSettings.SelectedItemStyle.BorderBrush = Brushes.SlateGray;
		}

		private void taskList_PreviewMouseDown(object sender, MouseButtonEventArgs e)
		{
			mouseDown = e.LeftButton == MouseButtonState.Pressed;
		}

		private void taskList_MouseMove(object sender, MouseEventArgs e)
		{
			if (taskList.SelectedItem != null && mouseDown)
			{
				mouseDown = false;
				string data = ((ListBoxItem)taskList.SelectedItem).Content.ToString();
				DragDrop.DoDragDrop(taskList, data, DragDropEffects.Copy);
			}
		}

		private void calendar_DragOver(object sender, DragEventArgs e)
		{
			e.Effects = DragDropEffects.None;
			if (e.Data.GetDataPresent(typeof(string)))
			{
				DateTime? date = calendar.GetDateAt(e.GetPosition(calendar));
				if (date != null)
					e.Effects = DragDropEffects.Copy;
			}
		}

		private void calendar_Drop(object sender, DragEventArgs e)
		{
			if (e.Data.GetDataPresent(typeof(string)))
			{
				Point point = e.GetPosition(calendar);
				DateTime? date = calendar.GetDateAt(point);
				Resource resource = calendar.GetResourceAt(point);
				if (date != null && resource != null)
				{
					string task = (string)e.Data.GetData(typeof(string));
					Appointment appointment = new Appointment();
					appointment.HeaderText = task;
					appointment.DescriptionText = "Description for " + task;
					appointment.StartTime = date.Value;
					appointment.EndTime = appointment.StartTime.AddDays(2);
					appointment.Resources.Add(resource);
					calendar.Schedule.Items.Add(appointment);
				}
			}
		}


		private bool mouseDown = false;
	}
}
